# Heat exchanger network synthesis

This project takes a look into how we can incorporate modular
manufacturing into heat exchanger network synthesis.

The project is currently prototype code that may later be
incorporated as a heat exchanger network synthesis unit model.
